@@ -13,16 +13,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef _ABOUT_DIALOG_H_
-#define _ABOUT_DIALOG_H_
+#ifndef ABOUT_DIALOG_H
+#define ABOUT_DIALOG_H
 
 #include <QDialog>
 #include <QString>
 
-class QWidget;
+#include "ui_about.h"
+
+/// @addtogroup GUI
+/// @{
 
 /**
 * @brief About dialog
@@ -35,7 +38,7 @@ public:
     AboutDialog(const QString &version, QWidget *parent = 0);
 
 private:
-    QString mVersion;
+    Ui::About mUI;
 };
-
-#endif // _ABOUT_DIALOG_H_
+/// @}
+#endif // ABOUT_DIALOG_H
