@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef APPLICATIONDIALOG_H
@@ -21,6 +21,10 @@
 
 #include <QDialog>
 #include <QLineEdit>
+#include "ui_application.h"
+
+/// @addtogroup GUI
+/// @{
 
 /**
 * @brief Dialog to edit a startable application.
@@ -70,19 +74,13 @@ protected slots:
     */
     void Browse();
 protected:
-    /**
-    * @brief Editbox for the application's name
-    * This is just a name to display the application. This has nothing to do
-    * with executing the application.
-    */
-    QLineEdit *mName;
 
     /**
-    * @brief Editbox for the application's path
-    * This also contains all parameters user wants to specify.
+    * @brief UI from the Qt designer
+    *
     */
-    QLineEdit *mPath;
+    Ui::ApplicationDialog mUI;
 private:
 };
-
+/// @}
 #endif // APPLICATIONDIALOG_H
