@@ -13,13 +13,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "applicationlist.h"
 #include <QStringList>
+#include "common.h"
 
-ApplicationList::ApplicationList()
+ApplicationList::ApplicationList(QObject *parent) :
+        QObject(parent)
 {
     //ctor
 }
@@ -29,42 +31,43 @@ ApplicationList::~ApplicationList()
     Clear();
 }
 
-void ApplicationList::LoadSettings(QSettings &programSettings)
+void ApplicationList::LoadSettings(QSettings *programSettings)
 {
 
-    QStringList names = programSettings.value(tr("Application names"), QStringList()).toStringList();
-    QStringList paths = programSettings.value(tr("Application paths"), QStringList()).toStringList();
+    QStringList names = programSettings->value(SETTINGS_APPLICATION_NAMES, QStringList()).toStringList();
+    QStringList paths = programSettings->value(SETTINGS_APPLICATION_PATHS, QStringList()).toStringList();
+
     if (names.size() == paths.size())
     {
-        for (int i = 0;i < names.size();i++)
+        for (int i = 0; i < names.size(); i++)
         {
             AddApplicationType(names[i], paths[i]);
         }
     }
 }
 
-void ApplicationList::SaveSettings(QSettings &programSettings)
+void ApplicationList::SaveSettings(QSettings *programSettings)
 {
     QStringList names;
     QStringList paths;
 
-    for (int i = 0;i < GetApplicationCount();i++)
+    for (int i = 0; i < GetApplicationCount(); i++)
     {
         names << GetApplicationName(i);
         paths << GetApplicationPath(i);
     }
 
-    programSettings.setValue(tr("Application names"), names);
-    programSettings.setValue(tr("Application paths"), paths);
+    programSettings->setValue(SETTINGS_APPLICATION_NAMES, names);
+    programSettings->setValue(SETTINGS_APPLICATION_PATHS, paths);
 
 }
 
-int ApplicationList::GetApplicationCount()
+int ApplicationList::GetApplicationCount() const
 {
     return mApplications.size();
 }
 
-QString ApplicationList::GetApplicationName(const int index)
+QString ApplicationList::GetApplicationName(const int index) const
 {
     if (index >= 0 && index < mApplications.size())
     {
@@ -74,7 +77,7 @@ QString ApplicationList::GetApplicationName(const int index)
     return QString();
 }
 
-QString ApplicationList::GetApplicationPath(const int index)
+QString ApplicationList::GetApplicationPath(const int index) const
 {
     if (index >= 0 && index < mApplications.size())
     {
@@ -125,12 +128,17 @@ void ApplicationList::MoveFirst(const int index)
 }
 
 
-void ApplicationList::Copy(ApplicationList &list)
+void ApplicationList::Copy(ApplicationList *list)
 {
-    Clear();
-    for (int i = 0;i < list.GetApplicationCount();i++)
+    if (!list)
     {
-        AddApplicationType(list.GetApplicationName(i), list.GetApplicationPath(i));
+        return;
+    }
+
+    Clear();
+    for (int i = 0; i < list->GetApplicationCount(); i++)
+    {
+        AddApplicationType(list->GetApplicationName(i), list->GetApplicationPath(i));
     }
 }
 
