@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -21,10 +21,13 @@
 #define CHECKTHREAD_H
 
 #include <QThread>
-#include "../src/cppcheck.h"
-#include "../src/settings.h"
+#include "../lib/cppcheck.h"
+#include "../lib/settings.h"
 #include "threadresult.h"
 
+/// @addtogroup GUI
+/// @{
+
 /**
 * @brief Thread to run cppcheck
 *
@@ -91,5 +94,5 @@ protected:
     CppCheck mCppcheck;
 private:
 };
-
+/// @}
 #endif // CHECKTHREAD_H
