@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -21,14 +21,23 @@
 #define MAINWINDOW_H
 
 #include <QMainWindow>
-#include "resultsview.h"
 #include <QSettings>
-#include <QAction>
 #include <QFileDialog>
+#include <QSignalMapper>
+#include <QActionGroup>
+#include <QToolBar>
 
-
-#include "threadhandler.h"
+#include "resultsview.h"
 #include "settingsdialog.h"
+#include "translationhandler.h"
+
+#include "ui_main.h"
+class ThreadHandler;
+
+
+/// @addtogroup GUI
+/// @{
+
 
 /**
 * @brief Main window for cppcheck-gui
@@ -43,6 +52,8 @@ public:
 
 public slots:
 
+
+
     /**
     * @brief Slot for check files menu item
     *
@@ -62,32 +73,26 @@ public slots:
     void ClearResults();
 
     /**
-    * @brief Show errors with type "all"
-    * @param checked Should errors be shown (truw) or hidden (false)
+    * @brief Show errors with type "possible error"
+    * @param checked Should errors be shown (true) or hidden (false)
     */
     void ShowAll(bool checked);
 
-    /**
-    * @brief Show errors with type "security"
-    * @param checked Should errors be shown (truw) or hidden (false)
-    */
-    void ShowSecurity(bool checked);
-
     /**
     * @brief Show errors with type "style"
-    * @param checked Should errors be shown (truw) or hidden (false)
+    * @param checked Should errors be shown (true) or hidden (false)
     */
     void ShowStyle(bool checked);
 
     /**
-    * @brief Show errors with type "unused"
-    * @param checked Should errors be shown (truw) or hidden (false)
+    * @brief Show errors with type "possible style"
+    * @param checked Should errors be shown (true) or hidden (false)
     */
-    void ShowUnused(bool checked);
+    void ShowAllStyle(bool checked);
 
     /**
     * @brief Show errors with type "error"
-    * @param checked Should errors be shown (truw) or hidden (false)
+    * @param checked Should errors be shown (true) or hidden (false)
     */
     void ShowErrors(bool checked);
 
@@ -119,6 +124,17 @@ public slots:
     */
     void About();
 
+    /**
+    * @brief Slot to to show license text
+    *
+    */
+    void ShowLicense();
+
+    /**
+    * @brief Slot to to show authors list
+    *
+    */
+    void ShowAuthors();
 
     /**
     * @brief Slot to stop processing files
@@ -139,8 +155,44 @@ protected slots:
     *
     */
     void ResultsAdded();
+
+
+    /**
+    * @brief Slot for changing the program's language
+    *
+    */
+    void MapLanguage(QAction *);
+
+    /**
+    * @brief Slot for showing/hiding standard toolbar
+    */
+    void ToggleToolbar();
+
+    /**
+    * @brief Slot for updating View-menu before it is shown.
+    */
+    void AboutToShowViewMenu();
+
+    /**
+    * @brief Slot when stop checking button is pressed
+    *
+    */
+    void StopChecking();
+
 protected:
 
+    /**
+    * @brief Create menu items to change language
+    *
+    */
+    void CreateLanguageMenuItems();
+
+    /**
+    * @brief Set current language
+    * @param index Index of the language to set
+    */
+    void SetLanguage(const int index);
+
     /**
     * @brief Event coming when application is about to close.
     */
@@ -159,11 +211,21 @@ protected:
     void EnableCheckButtons(bool enable);
 
     /**
-    * @brief Helper function to open a dialog to ask user to select files to check
+    * @brief Select files/or directory to check.
+    * Helper function to open a dialog to ask user to select files or
+    * directory to check. Use native dialogs instead of QT:s own dialogs.
     *
     * @param mode Dialog open mode (files or directories)
+    * @return QStringList of files or directories that were selected to check
     */
-    void DoCheckFiles(QFileDialog::FileMode mode);
+    QStringList SelectFilesToCheck(QFileDialog::FileMode mode);
+
+    /**
+    * @brief Check all files specified in parameter files
+    *
+    * @param files List of files and/or directories to check
+    */
+    void DoCheckFiles(const QStringList &files);
 
     /**
     * @brief Get all files recursively from given path
@@ -174,7 +236,7 @@ protected:
     QStringList GetFilesRecursively(const QString &path);
 
     /**
-    * @brief Get our default cppcheck settings
+    * @brief Get our default cppcheck settings and read project file.
     *
     * @return Default cppcheck settings
     */
@@ -200,140 +262,62 @@ protected:
     */
     void SaveSettings();
 
+    /**
+    * @brief Format main window title.
+    * @param text Text added to end of the title.
+    */
+    void FormatAndSetTitle(const QString &text = QString());
+
     /**
     * @brief Program settings
     *
     */
-    QSettings mSettings;
-
-    /**
-    * @brief Menu action to exit program
-    *
-    */
-    QAction mActionExit;
-
-    /**
-    * @brief Menu action to check files
-    *
-    */
-    QAction mActionCheckFiles;
-
-    /**
-    * @brief Menu action to clear results
-    *
-    */
-    QAction mActionClearResults;
-
-    /**
-    * @brief Menu action to re check
-    *
-    */
-    QAction mActionReCheck;
+    QSettings *mSettings;
 
 
-    /**
-    * @brief Menu action to check a directory
-    *
-    */
-    QAction mActionCheckDirectory;
 
-    /**
-    * @brief Menu action to open settings dialog
-    *
-    */
-    QAction mActionSettings;
-
-    /**
-    * @brief Action to show errors with type "all"
-    *
-    */
-    QAction mActionShowAll;
-
-    /**
-    * @brief Action to show errors with type "security"
-    *
-    */
-    QAction mActionShowSecurity;
-
-    /**
-    * @brief Action to show errors with type "style"
-    *
-    */
-    QAction mActionShowStyle;
-
-    /**
-    * @brief Action to show errors with type "unused"
-    *
-    */
-    QAction mActionShowUnused;
-
-    /**
-    * @brief Action to show errors with type "error"
-    *
-    */
-    QAction mActionShowErrors;
-
-    /**
-    * @brief Action to check all "show error" menu items
-    *
-    */
-    QAction mActionShowCheckAll;
-
-    /**
-    * @brief Action to uncheck all "show error" menu items
-    *
-    */
-    QAction mActionShowUncheckAll;
-
-    /**
-    * @brief Action to collapse all items in the result tree.
-    *
-    */
-    QAction mActionShowCollapseAll;
-
-    /**
-    * @brief Action to expand all items in the result tree.
-    *
-    */
-    QAction mActionShowExpandAll;
-
-    /**
-    * @brief Action show about dialog
-    *
-    */
-    QAction mActionAbout;
-
-    /**
-    * @brief Action stop checking files
-    *
-    */
-    QAction mActionStop;
-
-    /**
-    * @brief Action save found errors to a file
-    *
-    */
-    QAction mActionSave;
 
     /**
     * @brief Results for checking
     *
     */
-    ResultsView mResults;
+//    ResultsView mResults;
 
     /**
     * @brief Thread to check files
     *
     */
-    ThreadHandler mThread;
+    ThreadHandler *mThread;
 
     /**
     * @brief List of user defined applications to open errors with
     *
     */
-    ApplicationList mApplications;
+    ApplicationList *mApplications;
+
+    /**
+    * @brief Class to handle translation changes
+    *
+    */
+    TranslationHandler *mTranslation;
+
+    /**
+    * @brief Class holding all UI components
+    *
+    */
+    Ui::MainWindow mUI;
+
+    /**
+    * @brief Group holding all supported languages
+    *
+    */
+    QActionGroup *mLanguages;
+
+    /**
+    * @brief Current checked directory.
+    */
+    QString mCurrentDirectory;
 
-private:
 };
-
+/// @}
 #endif // MAINWINDOW_H
