@@ -13,39 +13,53 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
-#include "resultstree.h"
+#include <QApplication>
 #include <QDebug>
 #include <QMenu>
 #include <QSignalMapper>
 #include <QProcess>
 #include <QDir>
+#include <QMessageBox>
+#include <QFileInfo>
+#include <QClipboard>
+#include "resultstree.h"
+#include "xmlreport.h"
 
-ResultsTree::ResultsTree(QSettings &settings, ApplicationList &list) :
-        mSettings(settings),
-        mApplications(list),
+ResultsTree::ResultsTree(QWidget * parent) :
+        QTreeView(parent),
         mContextItem(0),
-        mCheckPath("")
+        mCheckPath(""),
+        mVisibleErrors(false)
 {
+    for (int i = 0; i < SHOW_NONE; i++)
+        mShowTypes[i] = false;
+
     setModel(&mModel);
     QStringList labels;
     labels << tr("File") << tr("Severity") << tr("Line") << tr("Message");
     mModel.setHorizontalHeaderLabels(labels);
     setExpandsOnDoubleClick(false);
     setSortingEnabled(true);
-    LoadSettings();
+
     connect(this, SIGNAL(doubleClicked(const QModelIndex &)),
             this, SLOT(QuickStartApplication(const QModelIndex &)));
 }
 
 ResultsTree::~ResultsTree()
 {
-    SaveSettings();
 }
 
+void ResultsTree::Initialize(QSettings *settings, ApplicationList *list)
+{
+    mSettings = settings;
+    mApplications = list;
+    LoadSettings();
+}
+
+
 QStandardItem *ResultsTree::CreateItem(const QString &name)
 {
     QStandardItem *item = new QStandardItem(name);
@@ -71,13 +85,20 @@ void ResultsTree::AddErrorItem(const QString &file,
 
     if (realfile.isEmpty())
     {
-        realfile = "Undefined file";
+        realfile = tr("Undefined file");
     }
 
     bool hide = !mShowTypes[SeverityToShowType(severity)];
+
+    //if there is at least one error that is not hidden, we have a visible error
+    if (!hide)
+    {
+        mVisibleErrors = true;
+    }
+
     //Create the base item for the error and ensure it has a proper
     //file item as a parent
-    QStandardItem *item = AddBacktraceFiles(EnsureFileItem(realfile),
+    QStandardItem *item = AddBacktraceFiles(EnsureFileItem(files[0], hide),
                                             realfile,
                                             lines[0].toInt(),
                                             severity,
@@ -85,26 +106,39 @@ void ResultsTree::AddErrorItem(const QString &file,
                                             hide,
                                             SeverityToIcon(severity));
 
+    if (!item)
+        return;
 
     //Add user data to that item
     QMap<QString, QVariant> data;
     data["severity"]  = SeverityToShowType(severity);
     data["message"]  = message;
-    data["files"]  = files;
-    data["lines"]  = lines;
+    data["file"]  = files[0];
+    data["line"]  = lines[0];
     data["id"]  = id;
     item->setData(QVariant(data));
 
     //Add backtrace files as children
-    for (int i = 1;i < files.size() && i < lines.size();i++)
+    for (int i = 1; i < files.size() && i < lines.size(); i++)
     {
-        AddBacktraceFiles(item,
-                          StripPath(files[i], false),
-                          lines[i].toInt(),
-                          severity,
-                          message,
-                          hide,
-                          ":images/go-down.png");
+        QStandardItem *child_item;
+
+        child_item = AddBacktraceFiles(item,
+                                       StripPath(files[i], false),
+                                       lines[i].toInt(),
+                                       severity,
+                                       message,
+                                       hide,
+                                       ":images/go-down.png");
+
+        //Add user data to that item
+        QMap<QString, QVariant> child_data;
+        child_data["severity"]  = SeverityToShowType(severity);
+        child_data["message"]  = message;
+        child_data["file"]  = files[i];
+        child_data["line"]  = lines[i];
+        child_data["id"]  = id;
+        child_item->setData(QVariant(child_data));
     }
 
     //TODO just hide/show current error and it's file
@@ -131,11 +165,32 @@ QStandardItem *ResultsTree::AddBacktraceFiles(QStandardItem *parent,
 
     QList<QStandardItem*> list;
     list << CreateItem(file);
-    list << CreateItem(severity);
+    list << CreateItem(tr(severity.toLatin1()));
     list << CreateItem(QString("%1").arg(line));
-    list << CreateItem(message);
+    //TODO message has parameter names so we'll need changes to the core
+    //cppcheck so we can get proper translations
+    list << CreateItem(tr(message.toLatin1()));
 
-    QModelIndex index = QModelIndex();
+    // Check for duplicate rows and don't add them if found
+    for (int i = 0; i < parent->rowCount(); i++)
+    {
+        // the first column is the file name and is always the same so skip it
+
+        // the third column is the line number so check it first
+        if (parent->child(i, 2)->text() == list[2]->text())
+        {
+            // the second column is the severity so check it next
+            if (parent->child(i, 1)->text() == list[1]->text())
+            {
+                // the forth column is the message so check it last
+                if (parent->child(i, 3)->text() == list[3]->text())
+                {
+                    // this row matches so don't add it
+                    return 0;
+                }
+            }
+        }
+    }
 
     parent->appendRow(list);
 
@@ -163,14 +218,14 @@ ShowTypes ResultsTree::VariantToShowType(const QVariant &data)
 
 ShowTypes ResultsTree::SeverityToShowType(const QString & severity)
 {
-    if (severity == "all")
+    if (severity == "possible error")
         return SHOW_ALL;
     if (severity == "error")
         return SHOW_ERRORS;
     if (severity == "style")
         return SHOW_STYLE;
-    if (severity == "security")
-        return SHOW_SECURITY;
+    if (severity == "possible style")
+        return SHOW_ALL_STYLE;
 
     return SHOW_NONE;
 }
@@ -192,24 +247,24 @@ void ResultsTree::Clear()
 
 void ResultsTree::LoadSettings()
 {
-    for (int i = 0;i < mModel.columnCount();i++)
+    for (int i = 0; i < mModel.columnCount(); i++)
     {
         //mFileTree.columnWidth(i);
-        QString temp = QString(tr("Result column %1 width")).arg(i);
-        setColumnWidth(i, mSettings.value(temp, 800 / mModel.columnCount()).toInt());
+        QString temp = QString(SETTINGS_RESULT_COLUMN_WIDTH).arg(i);
+        setColumnWidth(i, mSettings->value(temp, 800 / mModel.columnCount()).toInt());
     }
 
-    mSaveFullPath = mSettings.value(tr("Save full path"), false).toBool();
-    mSaveAllErrors = mSettings.value(tr("Save all errors"), false).toBool();
-    mShowFullPath = mSettings.value(tr("Show full path"), false).toBool();
+    mSaveFullPath = mSettings->value(SETTINGS_SAVE_FULL_PATH, false).toBool();
+    mSaveAllErrors = mSettings->value(SETTINGS_SAVE_ALL_ERRORS, false).toBool();
+    mShowFullPath = mSettings->value(SETTINGS_SHOW_FULL_PATH, false).toBool();
 }
 
 void ResultsTree::SaveSettings()
 {
-    for (int i = 0;i < mModel.columnCount();i++)
+    for (int i = 0; i < mModel.columnCount(); i++)
     {
-        QString temp = QString(tr("Result column %1 width")).arg(i);
-        mSettings.setValue(temp, columnWidth(i));
+        QString temp = QString(SETTINGS_RESULT_COLUMN_WIDTH).arg(i);
+        mSettings->setValue(temp, columnWidth(i));
     }
 }
 
@@ -225,10 +280,11 @@ void ResultsTree::ShowResults(ShowTypes type, bool show)
 
 void ResultsTree::RefreshTree()
 {
+    mVisibleErrors = false;
     //Get the amount of files in the tree
     int filecount = mModel.rowCount();
 
-    for (int i = 0;i < filecount;i++)
+    for (int i = 0; i < filecount; i++)
     {
         //Get file i
         QStandardItem *file = mModel.item(i, 0);
@@ -243,7 +299,7 @@ void ResultsTree::RefreshTree()
         //By default it shouldn't be visible
         bool show = false;
 
-        for (int j = 0;j < errorcount;j++)
+        for (int j = 0; j < errorcount; j++)
         {
             //Get the error itself
             QStandardItem *child = file->child(j, 0);
@@ -260,10 +316,15 @@ void ResultsTree::RefreshTree()
             //Check if this error should be hidden
             bool hide = !mShowTypes[VariantToShowType(data["severity"])];
 
+            if (!hide)
+            {
+                mVisibleErrors = true;
+            }
+
             //Hide/show accordingly
             setRowHidden(j, file->index(), hide);
 
-            //If it was shown then the file itself has to be shown aswell
+            //If it was shown then the file itself has to be shown as well
             if (!hide)
             {
                 show = true;
@@ -275,9 +336,9 @@ void ResultsTree::RefreshTree()
     }
 }
 
-
-QStandardItem *ResultsTree::EnsureFileItem(const QString &name)
+QStandardItem *ResultsTree::EnsureFileItem(const QString &fullpath, bool hide)
 {
+    QString name = StripPath(fullpath, false);
     QStandardItem *item = FindFileItem(name);
 
     if (item)
@@ -288,8 +349,14 @@ QStandardItem *ResultsTree::EnsureFileItem(const QString &name)
     item = CreateItem(name);
     item->setIcon(QIcon(":images/text-x-generic.png"));
 
+    //Add user data to that item
+    QMap<QString, QVariant> data;
+    data["file"] = fullpath;
+    item->setData(QVariant(data));
     mModel.appendRow(item);
 
+    setRowHidden(mModel.rowCount() - 1, QModelIndex(), hide);
+
     return item;
 }
 
@@ -308,23 +375,24 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
     if (index.isValid())
     {
         mContextItem = mModel.itemFromIndex(index);
-        if (mContextItem && mApplications.GetApplicationCount() > 0 && mContextItem->parent())
+
+        //Create a new context menu
+        QMenu menu(this);
+
+        //Store all applications in a list
+        QList<QAction*> actions;
+
+        //Create a signal mapper so we don't have to store data to class
+        //member variables
+        QSignalMapper *signalMapper = new QSignalMapper(this);
+
+        if (mContextItem && mApplications->GetApplicationCount() > 0 && mContextItem->parent())
         {
-
-            //Create a new context menu
-            QMenu menu(this);
-            //Store all applications in a list
-            QList<QAction*> actions;
-
-            //Create a signal mapper so we don't have to store data to class
-            //member variables
-            QSignalMapper *signalMapper = new QSignalMapper(this);
-
             //Go through all applications and add them to the context menu
-            for (int i = 0;i < mApplications.GetApplicationCount();i++)
+            for (int i = 0; i < mApplications->GetApplicationCount(); i++)
             {
                 //Create an action for the application
-                QAction *start = new QAction(mApplications.GetApplicationName(i), &menu);
+                QAction *start = new QAction(mApplications->GetApplicationName(i), &menu);
 
                 //Add it to our list so we can disconnect later on
                 actions << start;
@@ -341,18 +409,42 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
 
             connect(signalMapper, SIGNAL(mapped(int)),
                     this, SLOT(Context(int)));
+        }
 
-            //Start the menu
-            menu.exec(e->globalPos());
+        // Add menuitems to copy full path/filename to clipboard
+        if (mContextItem)
+        {
+            if (mApplications->GetApplicationCount() > 0)
+            {
+                menu.addSeparator();
+            }
 
+            //Create an action for the application
+            QAction *copyfilename 	= new QAction(tr("Copy filename"), &menu);
+            QAction *copypath 		= new QAction(tr("Copy full path"), &menu);
+            QAction *copymessage 	= new QAction(tr("Copy message"), &menu);
+
+            menu.addAction(copyfilename);
+            menu.addAction(copypath);
+            menu.addAction(copymessage);
+
+            connect(copyfilename, SIGNAL(triggered()), this, SLOT(CopyFilename()));
+            connect(copypath, SIGNAL(triggered()), this, SLOT(CopyFullPath()));
+            connect(copymessage, SIGNAL(triggered()), this, SLOT(CopyMessage()));
+        }
+
+        //Start the menu
+        menu.exec(e->globalPos());
+
+        if (mContextItem && mApplications->GetApplicationCount() > 0 && mContextItem->parent())
+        {
             //Disconnect all signals
-            for (int i = 0;i < actions.size();i++)
+            for (int i = 0; i < actions.size(); i++)
             {
 
                 disconnect(actions[i], SIGNAL(triggered()), signalMapper, SLOT(map()));
             }
 
-
             disconnect(signalMapper, SIGNAL(mapped(int)),
                        this, SLOT(Context(int)));
             //And remove the signal mapper
@@ -364,44 +456,86 @@ void ResultsTree::contextMenuEvent(QContextMenuEvent * e)
 
 void ResultsTree::StartApplication(QStandardItem *target, int application)
 {
-    if (target && application >= 0 && application < mApplications.GetApplicationCount() && target->parent())
+    //If there are now application's specified, tell the user about it
+    if (mApplications->GetApplicationCount() == 0)
     {
+        QMessageBox msg(QMessageBox::Information,
+                        tr("Cppcheck"),
+                        tr("Configure the text file viewer program in Cppcheck preferences/Applications."),
+                        QMessageBox::Ok,
+                        this);
+        msg.exec();
+        return;
+    }
+
+    if (target && application >= 0 && application < mApplications->GetApplicationCount() && target->parent())
+    {
+        // Make sure we are working with the first column
+        if (target->column() != 0)
+            target = target->parent()->child(target->row(), 0);
+
         QVariantMap data = target->data().toMap();
 
-        QString program = mApplications.GetApplicationPath(application);
-
-        //TODO Check which line was actually right clicked, now defaults to 0
-        unsigned int index = 0;
+        QString program = mApplications->GetApplicationPath(application);
 
         //Replace (file) with filename
-        QStringList files = data["files"].toStringList();
-        if (files.size() > 0)
+        QString file = data["file"].toString();
+        if (file.indexOf(" ") > -1)
         {
-            program.replace("(file)", files[index], Qt::CaseInsensitive);
-        }
-        else
-        {
-            qDebug("Failed to get filename!");
+            file.insert(0, "\"");
+            file.append("\"");
         }
 
+        program.replace("(file)", file, Qt::CaseInsensitive);
 
-        QVariantList lines = data["lines"].toList();
-        if (lines.size() > 0)
-        {
-            program.replace("(line)", QString("%1").arg(lines[index].toInt()), Qt::CaseInsensitive);
-        }
-        else
-        {
-            qDebug("Failed to get filenumber!");
-        }
+        QVariant line = data["line"];
+        program.replace("(line)", QString("%1").arg(line.toInt()), Qt::CaseInsensitive);
 
         program.replace("(message)", data["message"].toString(), Qt::CaseInsensitive);
         program.replace("(severity)", data["severity"].toString(), Qt::CaseInsensitive);
 
-        QProcess::startDetached(program);
+        bool success = QProcess::startDetached(program);
+        if (!success)
+        {
+            QString app = mApplications->GetApplicationName(application);
+            QString text = tr("Could not start %1\n\nPlease check the application path and parameters are correct.").arg(app);
+
+            QMessageBox msgbox(this);
+            msgbox.setWindowTitle("Cppcheck");
+            msgbox.setText(text);
+            msgbox.setIcon(QMessageBox::Critical);
+
+            msgbox.exec();
+        }
     }
 }
 
+void ResultsTree::CopyFilename()
+{
+    CopyPath(mContextItem, false);
+}
+
+void ResultsTree::CopyFullPath()
+{
+    CopyPath(mContextItem, true);
+}
+
+void ResultsTree::CopyMessage()
+{
+    if (mContextItem)
+    {
+        // Make sure we are working with the first column
+        if (mContextItem->column() != 0)
+            mContextItem = mContextItem->parent()->child(mContextItem->row(), 0);
+
+        QVariantMap data = mContextItem->data().toMap();
+
+        QString message = data["message"].toString();
+
+        QClipboard *clipboard = QApplication::clipboard();
+        clipboard->setText(message);
+    }
+}
 
 void ResultsTree::Context(int application)
 {
@@ -413,38 +547,58 @@ void ResultsTree::QuickStartApplication(const QModelIndex &index)
     StartApplication(mModel.itemFromIndex(index), 0);
 }
 
+void ResultsTree::CopyPath(QStandardItem *target, bool fullPath)
+{
+    if (target)
+    {
+        // Make sure we are working with the first column
+        if (target->column() != 0)
+            target = target->parent()->child(target->row(), 0);
+
+        QVariantMap data = target->data().toMap();
+        QString pathStr;
+
+        //Replace (file) with filename
+        QString file = data["file"].toString();
+        pathStr = file;
+        if (!fullPath)
+        {
+            QFileInfo fi(pathStr);
+            pathStr = fi.fileName();
+        }
+
+        QClipboard *clipboard = QApplication::clipboard();
+        clipboard->setText(pathStr);
+    }
+}
+
 QString ResultsTree::SeverityToIcon(const QString &severity)
 {
-    if (severity == "all")
+    if (severity == "possible error")
         return ":images/dialog-warning.png";
     if (severity == "error")
         return ":images/dialog-error.png";
-    if (severity == "style")
+    if (severity == "style" || severity == "possible style")
         return ":images/dialog-information.png";
 
     return "";
 }
 
-void ResultsTree::SaveResults(QTextStream &out, bool xml)
+void ResultsTree::SaveResults(Report *report)
 {
-    if (xml)
-    {
-        out << "<?xml version=\"1.0\"?>" << endl << "<results>" << endl;
-    }
+    report->WriteHeader();
 
-    for (int i = 0;i < mModel.rowCount();i++)
+    for (int i = 0; i < mModel.rowCount(); i++)
     {
         QStandardItem *item = mModel.item(i, 0);
-        SaveErrors(out, item, xml);
+        if (!isRowHidden(i, item->index()))
+            SaveErrors(report, item);
     }
 
-    if (xml)
-    {
-        out << "</results>" << endl;
-    }
+    report->WriteFooter();
 }
 
-void ResultsTree::SaveErrors(QTextStream &out, QStandardItem *item, bool xml)
+void ResultsTree::SaveErrors(Report *report, QStandardItem *item)
 {
     if (!item)
     {
@@ -453,7 +607,7 @@ void ResultsTree::SaveErrors(QTextStream &out, QStandardItem *item, bool xml)
 
     //qDebug() << item->text() << "has" << item->rowCount() << "errors";
 
-    for (int i = 0;i < item->rowCount();i++)
+    for (int i = 0; i < item->rowCount(); i++)
     {
         QStandardItem *error = item->child(i, 0);
 
@@ -472,59 +626,34 @@ void ResultsTree::SaveErrors(QTextStream &out, QStandardItem *item, bool xml)
         //Convert it to QVariantMap
         QVariantMap data = userdata.toMap();
 
-        QString line;
         QString severity = ShowTypeToString(VariantToShowType(data["severity"]));
         QString message = data["message"].toString();
         QString id = data["id"].toString();
-        QStringList files = data["files"].toStringList();
-        QVariantList lines = data["lines"].toList();
+        QString file = StripPath(data["file"].toString(), true);
+        QString line = data["line"].toString();
 
-        if (files.size() <= 0 || lines.size() <= 0 || lines.size() != files.size())
+        QStringList files;
+        QStringList lines;
+
+        files << file;
+        lines << line;
+
+        for (int j = 0; j < error->rowCount(); j++)
         {
-            continue;
+            QStandardItem *child_error = error->child(j, 0);
+            //Get error's user data
+            QVariant child_userdata = child_error->data();
+            //Convert it to QVariantMap
+            QVariantMap child_data = child_userdata.toMap();
+
+            file = StripPath(child_data["file"].toString(), true);
+            line = child_data["line"].toString();
+
+            files << file;
+            lines << line;
         }
 
-
-
-        if (xml)
-        {
-            /*
-            Error example from the core program in xml
-            <error file="gui/test.cpp" line="14" id="mismatchAllocDealloc" severity="error" msg="Mismatching allocation and deallocation: k"/>
-            The callstack seems to be ignored here aswell, instead last item of the stack is used
-            */
-            line = QString("<error file=\"%1\" line=\"%2\" id=\"%3\" severity=\"%4\" msg=\"%5\"/>").
-                   arg(StripPath(files[files.size()-1], true)). //filename
-                   arg(lines[lines.size()-1].toInt()). //line
-                   arg(id). //ID
-                   arg(severity). //severity
-                   arg(message); //Message
-
-        }
-        else
-        {
-            /*
-            Error example from the core program in text
-            [gui/test.cpp:23] -> [gui/test.cpp:14]: (error) Mismatching allocation and deallocation: k
-            */
-            for (int i = 0;i < lines.size();i++)
-            {
-                line += QString("[%1:%2]").arg(StripPath(files[i], true)).arg(lines[i].toInt());
-                if (i < lines.size() - 1 && lines.size() > 0)
-                {
-                    line += " -> ";
-                }
-
-                if (i == lines.size() - 1)
-                {
-                    line += ": ";
-                }
-            }
-
-            line += QString("(%1) %2").arg(severity).arg(message);
-        }
-
-        out << line << endl;
+        report->WriteError(files, lines, id, severity, message);
     }
 }
 
@@ -533,23 +662,19 @@ QString ResultsTree::ShowTypeToString(ShowTypes type)
     switch (type)
     {
     case SHOW_ALL:
-        return "all";
+        return tr("possible error");
         break;
 
     case SHOW_STYLE:
-        return "style";
+        return tr("style");
         break;
 
-    case SHOW_SECURITY:
-        return "security";
-        break;
-
-    case SHOW_UNUSED:
-        return "unused";
+    case SHOW_ALL_STYLE:
+        return tr("possible style");
         break;
 
     case SHOW_ERRORS:
-        return "error";
+        return tr("error");
         break;
 
     case SHOW_NONE:
@@ -601,7 +726,7 @@ void ResultsTree::RefreshFilePaths(QStandardItem *item)
     bool updated = false;
 
     //Loop through all errors within this file
-    for (int i = 0;i < item->rowCount();i++)
+    for (int i = 0; i < item->rowCount(); i++)
     {
         //Get error i
         QStandardItem *error = item->child(i, 0);
@@ -617,31 +742,32 @@ void ResultsTree::RefreshFilePaths(QStandardItem *item)
         QVariantMap data = userdata.toMap();
 
         //Get list of files
-        QStringList files = data["files"].toStringList();
-
-        //We should always have at least 1 file per error
-        if (files.size() == 0)
-        {
-            continue;
-        }
+        QString file = data["file"].toString();
 
         //Update this error's text
-        error->setText(StripPath(files[0], false));
+        error->setText(StripPath(file, false));
 
         //If this error has backtraces make sure the files list has enough filenames
-        if (error->rowCount() <= files.size() - 1)
+        if (error->hasChildren())
         {
             //Loop through all files within the error
-            for (int j = 0;j < error->rowCount();j++)
+            for (int j = 0; j < error->rowCount(); j++)
             {
                 //Get file
-                QStandardItem *file = error->child(j, 0);
-                if (!file)
+                QStandardItem *child = error->child(j, 0);
+                if (!child)
                 {
                     continue;
                 }
+                //Get childs's user data
+                QVariant child_userdata = child->data();
+                //Convert it to QVariantMap
+                QVariantMap child_data = child_userdata.toMap();
+
+                //Get list of files
+                QString child_files = child_data["file"].toString();
                 //Update file's path
-                file->setText(StripPath(files[j+1], false));
+                child->setText(StripPath(child_files, false));
             }
         }
 
@@ -660,8 +786,27 @@ void ResultsTree::RefreshFilePaths()
     qDebug("Refreshing file paths");
 
     //Go through all file items (these are parent items that contain the errors)
-    for (int i = 0;i < mModel.rowCount();i++)
+    for (int i = 0; i < mModel.rowCount(); i++)
     {
         RefreshFilePaths(mModel.item(i, 0));
     }
 }
+
+bool ResultsTree::HasVisibleResults() const
+{
+    return mVisibleErrors;
+}
+
+bool ResultsTree::HasResults() const
+{
+    return mModel.rowCount() > 0;
+}
+
+void ResultsTree::Translate()
+{
+    QStringList labels;
+    labels << tr("File") << tr("Severity") << tr("Line") << tr("Message");
+    mModel.setHorizontalHeaderLabels(labels);
+    //TODO go through all the errors in the tree and translate severity and message
+}
+
