@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -23,10 +23,14 @@
 
 #include <QWidget>
 #include <QProgressBar>
-#include "../src/errorlogger.h"
+#include "../lib/errorlogger.h"
 #include "resultstree.h"
 #include "common.h"
+#include "report.h"
+#include "ui_resultsview.h"
 
+/// @addtogroup GUI
+/// @{
 
 /**
 * @brief Widget to show cppcheck progressbar and result
@@ -37,7 +41,8 @@ class ResultsView : public QWidget
     Q_OBJECT
 public:
 
-    ResultsView(QSettings &settings, ApplicationList &list);
+    ResultsView(QWidget * parent = 0);
+    void Initialize(QSettings *settings, ApplicationList *list);
     virtual ~ResultsView();
 
     /**
@@ -59,9 +64,9 @@ public:
     * @brief Save results to a file
     *
     * @param filename Filename to save results to
-    * @param xml should results be saved as xml (true) or txt (false)
+    * @param type Type of the report.
     */
-    void Save(const QString &filename, bool xml);
+    void Save(const QString &filename, Report::Type type);
 
     /**
     * @brief Update tree settings
@@ -70,7 +75,10 @@ public:
     * @param saveFullPath Save full path of files in reports
     * @param saveAllErrors Save all visible errors
     */
-    void UpdateSettings(bool showFullPath, bool saveFullPath, bool saveAllErrors);
+    void UpdateSettings(bool showFullPath,
+                        bool saveFullPath,
+                        bool saveAllErrors,
+                        bool showNoErrorsMessage);
 
     /**
     * @brief Set the directory we are checking
@@ -80,6 +88,40 @@ public:
     */
     void SetCheckDirectory(const QString &dir);
 
+    /**
+    * @brief Inform the view that checking has started
+    *
+    * At the moment this only displays the progressbar
+    */
+    void CheckingStarted();
+
+    /**
+    * @brief Do we have visible results to show?
+    *
+    * @return true if there is at least one warning/error to show.
+    */
+    bool HasVisibleResults() const;
+
+    /**
+    * @brief Do we have results from check?
+    *
+    * @return true if there is at least one warning/error, hidden or visible.
+    */
+    bool HasResults() const;
+
+    /**
+    * @brief Save View's settings
+    *
+    */
+    void SaveSettings();
+
+    /**
+    * @brief Translate this view
+    *
+    */
+    void Translate();
+
+    void DisableProgressbar();
 signals:
 
     /**
@@ -127,18 +169,18 @@ public slots:
 
 protected:
     /**
-    * @brief Tree to show cppcheck's results
-    *
+    * @brief Have any errors been found
     */
-    ResultsTree *mTree;
+    bool mErrorsFound;
 
     /**
-    * @brief Progressbar to show cppcheck's progress
-    *
+    * @brief Should we show a "No errors found dialog" everytime no errors were found?
     */
-    QProgressBar *mProgress;
+    bool mShowNoErrorsMessage;
+
+    Ui::ResultsView mUI;
 
 private:
 };
-
+/// @}
 #endif // RESULTSVIEW_H
