@@ -13,14 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
 #include "threadhandler.h"
 #include <QDebug>
 
-ThreadHandler::ThreadHandler() : mRunningThreadCount(0)
+ThreadHandler::ThreadHandler(QObject *parent) :
+        QObject(parent),
+        mRunningThreadCount(0)
 {
     SetThreadCount(1);
 }
@@ -65,7 +67,7 @@ void ThreadHandler::Check(Settings settings, bool recheck)
         mRunningThreadCount = mResults.GetFileCount();
     }
 
-    for (int i = 0;i < mRunningThreadCount;i++)
+    for (int i = 0; i < mRunningThreadCount; i++)
     {
         mThreads[i]->Check(settings);
     }
@@ -88,7 +90,7 @@ void ThreadHandler::SetThreadCount(const int count)
     //Remove unused old threads
     RemoveThreads();
     //Create new threads
-    for (int i = mThreads.size();i < count;i++)
+    for (int i = mThreads.size(); i < count; i++)
     {
         mThreads << new CheckThread(mResults);
         connect(mThreads.last(), SIGNAL(Done()),
@@ -102,7 +104,7 @@ void ThreadHandler::SetThreadCount(const int count)
 
 void ThreadHandler::RemoveThreads()
 {
-    for (int i = 0;i < mThreads.size();i++)
+    for (int i = 0; i < mThreads.size(); i++)
     {
         mThreads[i]->terminate();
         disconnect(mThreads.last(), SIGNAL(Done()),
@@ -127,7 +129,7 @@ void ThreadHandler::ThreadDone()
 
 void ThreadHandler::Stop()
 {
-    for (int i = 0;i < mThreads.size();i++)
+    for (int i = 0; i < mThreads.size(); i++)
     {
         mThreads[i]->stop();
     }
@@ -156,11 +158,18 @@ void ThreadHandler::Initialize(ResultsView *view)
 
 void ThreadHandler::LoadSettings(QSettings &settings)
 {
-    SetThreadCount(settings.value(tr("Check threads"), 1).toInt());
+    SetThreadCount(settings.value(SETTINGS_CHECK_THREADS, 1).toInt());
 }
 
 void ThreadHandler::SaveSettings(QSettings &settings)
 {
-    settings.setValue(tr("Check threads"), mThreads.size());
+    settings.setValue(SETTINGS_CHECK_THREADS, mThreads.size());
 }
 
+bool ThreadHandler::HasPreviousFiles() const
+{
+    if (mLastFiles.size() > 0)
+        return true;
+
+    return false;
+}
