@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -22,12 +22,16 @@
 
 #include <QObject>
 #include <QStringList>
-#include "../src/settings.h"
-#include "../src/cppcheck.h"
+#include "../lib/settings.h"
+#include "../lib/cppcheck.h"
 #include "threadresult.h"
 #include "checkthread.h"
 #include "resultsview.h"
 
+/// @addtogroup GUI
+/// @{
+
+
 /**
 * @brief This class handles creating threadresult and starting threads
 *
@@ -36,7 +40,7 @@ class ThreadHandler : public QObject
 {
     Q_OBJECT
 public:
-    ThreadHandler();
+    ThreadHandler(QObject *parent = 0);
     virtual ~ThreadHandler();
 
     /**
@@ -92,19 +96,30 @@ public:
     */
     bool IsChecking() const;
 
+    /**
+    * @brief Have we checked files already?
+    *
+    * @return true check has been previously run and recheck can be done
+    */
+    bool HasPreviousFiles() const;
+
 signals:
     /**
     * @brief Signal that all threads are done
     *
     */
     void Done();
-protected slots:
+
+public slots:
 
     /**
     * @brief Slot to stop all threads
     *
     */
     void Stop();
+protected slots:
+
+
 
     /**
     * @brief Slot that a single thread is done
@@ -143,5 +158,5 @@ protected:
     int mRunningThreadCount;
 private:
 };
-
+/// @}
 #endif // THREADHANDLER_H
