@@ -13,12 +13,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
-#include "../src/tokenize.h"
-#include "../src/checkautovariables.h"
+#include "tokenize.h"
+#include "checkautovariables.h"
 #include "testsuite.h"
 
 #include <sstream>
@@ -54,16 +54,21 @@ private:
 
         // Check auto variables
         Settings settings;
-        settings._showAll = true;
         CheckAutoVariables checkAutoVariables(&tokenizer, &settings, this);
         checkAutoVariables.autoVariables();
+        checkAutoVariables.returnPointerToLocalArray();
     }
 
     void run()
     {
         TEST_CASE(testautovar);
-        TEST_CASE(testautovararray);
-        TEST_CASE(testautovarreturn);
+        TEST_CASE(testautovar_array);
+        TEST_CASE(testautovar_return);
+        TEST_CASE(testautovar_extern);
+        TEST_CASE(testinvaliddealloc);
+
+        TEST_CASE(returnLocalVariable1);
+        TEST_CASE(returnLocalVariable2);
     }
 
 
@@ -72,9 +77,10 @@ private:
     {
         check("void func1(int **res)\n"
               "{\n"
-              "    int num=2;"
-              "res=&num;}");
-        ASSERT_EQUALS("[test.cpp:3]: (error) Wrong assignement of an auto-variable to an effective parameter of a function\n", errout.str());
+              "    int num = 2;\n"
+              "    *res = &num;\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:3]: (error) Wrong assignment of an auto-variable to an effective parameter of a function\n", errout.str());
 
         check("void func1(int **res)\n"
               "{\n"
@@ -83,15 +89,17 @@ private:
               "}");
         ASSERT_EQUALS("", errout.str());
     }
-    void testautovararray()
+
+    void testautovar_array()
     {
         check("void func1(int* arr[2])\n"
               "{\n"
               "    int num=2;"
               "arr[0]=&num;}");
-        ASSERT_EQUALS("[test.cpp:3]: (error) Wrong assignement of an auto-variable to an effective parameter of a function\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:3]: (error) Wrong assignment of an auto-variable to an effective parameter of a function\n", errout.str());
     }
-    void testautovarreturn()
+
+    void testautovar_return()
     {
         check("int* func1()\n"
               "{\n"
@@ -99,6 +107,58 @@ private:
               "return &num;}");
         ASSERT_EQUALS("[test.cpp:3]: (error) Return of the address of an auto-variable\n", errout.str());
     }
+
+    void testautovar_extern()
+    {
+        check("struct foo *f()\n"
+              "{\n"
+              "    extern struct foo f;\n"
+              "    return &f;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void testinvaliddealloc()
+    {
+        check("int* func1()\n"
+              "{\n"
+              "int a;\n"
+              "char tmp[256];\n"
+              "free (tmp);\n"
+              "}\n");
+        ASSERT_EQUALS(std::string("[test.cpp:5]: (error) Invalid deallocation\n"), errout.str());
+
+        check("void f()\n"
+              "{\n"
+              "    char psz_title[10];\n"
+              "    {\n"
+              "        char *psz_title = 0;\n"
+              "        abc(0, psz_title);\n"
+              "        free(psz_title);\n"
+              "    }\n"
+              "}\n");
+        ASSERT_EQUALS(std::string(""), errout.str());
+    }
+
+    void returnLocalVariable1()
+    {
+        check("char *foo()\n"
+              "{\n"
+              "    char str[100] = {0};\n"
+              "    return str;\n"
+              "}\n");
+        ASSERT_EQUALS("[test.cpp:4]: (error) Returning pointer to local array variable\n", errout.str());
+    }
+
+    void returnLocalVariable2()
+    {
+        check("std::string foo()\n"
+              "{\n"
+              "    char str[100] = {0};\n"
+              "    return str;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestAutoVariables)
