@@ -13,12 +13,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
-#include "../src/tokenize.h"
-#include "../src/checkother.h"
+#include "tokenize.h"
+#include "checkother.h"
 #include "testsuite.h"
 #include <sstream>
 
@@ -39,6 +39,8 @@ private:
         TEST_CASE(bitop1);
         TEST_CASE(bitop2);
         TEST_CASE(return1);
+        TEST_CASE(assignChar);
+        TEST_CASE(and03);
     }
 
     void check(const char code[])
@@ -55,7 +57,7 @@ private:
         // Check char variable usage..
         Settings settings;
         CheckOther checkOther(&tokenizer, &settings, this);
-        checkOther.CheckCharVariable();
+        checkOther.checkCharVariable();
     }
 
     void array_index()
@@ -93,6 +95,7 @@ private:
     {
         check("void foo()\n"
               "{\n"
+              "    int result = 0;\n"
               "    char ch;\n"
               "    result = a | ch;\n"
               "}\n");
@@ -118,6 +121,28 @@ private:
               "}\n");
         ASSERT_EQUALS("", errout.str());
     }
+
+
+    void assignChar()
+    {
+        check("void foo()\n"
+              "{\n"
+              "    char c;\n"
+              "    c = c & 0x123;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
+    void and03()
+    {
+        check("void foo()\n"
+              "{\n"
+              "    char c;\n"
+              "    int i = c & 0x03;\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
+    }
+
 };
 
 REGISTER_TEST(TestCharVar)
