@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
-// The preprocessor that c++check uses is a bit special. Instead of generating
+// The preprocessor that Cppcheck uses is a bit special. Instead of generating
 // the code for a known configuration, it generates the code for each configuration.
 
 
+#include "cppcheck.h"
 #include "testsuite.h"
-#include "../src/cppcheck.h"
 
 #include <map>
 #include <string>
@@ -53,6 +53,7 @@ private:
         TEST_CASE(xml);
 
         TEST_CASE(include);
+        TEST_CASE(templateFormat);
     }
 
     void linenumbers()
@@ -66,7 +67,8 @@ private:
         check(filedata);
 
         // Compare results..
-        ASSERT_EQUALS("[file.cpp:5]: (error) Using 'foo' after it is deallocated / released\n", errout.str());
+        ASSERT_EQUALS("Checking file.cpp...\n"
+                      "[file.cpp:5]: (error) Dereferencing 'foo' after it is deallocated / released\n", errout.str());
     }
 
     void linenumbers2()
@@ -104,6 +106,20 @@ private:
         ASSERT_EQUALS("[ab/ef.h:0]: ", errmsg.toText());
     }
 
+    void templateFormat()
+    {
+        ErrorLogger::ErrorMessage errmsg;
+        ErrorLogger::ErrorMessage::FileLocation loc;
+        loc.file = "some/{file}file.cpp";
+        loc.line = 10;
+        errmsg._callStack.push_back(loc);
+        errmsg._id = "testId";
+        errmsg._severity = "testSeverity";
+        errmsg._msg = "long testMessage";
+        ASSERT_EQUALS("<error file=\"some/{file}file.cpp\" line=\"10\" id=\"testId\" severity=\"testSeverity\" msg=\"long testMessage\"/>", errmsg.toXML());
+        ASSERT_EQUALS("[some/{file}file.cpp:10]: (testSeverity) long testMessage", errmsg.toText());
+        ASSERT_EQUALS("testId-some/{file}file.cpp,testSeverity.10?{long testMessage}", errmsg.toText("{id}-{file},{severity}.{line}?{{message}}"));
+    }
 };
 
 REGISTER_TEST(TestCppcheck)
