@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -21,8 +21,8 @@
 // such as "svar / uvar". Treating "svar" as unsigned data is not good
 
 
-#include "../src/tokenize.h"
-#include "../src/checkother.h"
+#include "tokenize.h"
+#include "checkother.h"
 #include "testsuite.h"
 
 #include <sstream>
@@ -36,7 +36,7 @@ public:
     { }
 
 private:
-    void check(const char code[])
+    void check(const char code[], bool style = true, bool all = true)
     {
         // Tokenize..
         Tokenizer tokenizer;
@@ -47,12 +47,12 @@ private:
         errout.str("");
 
         Settings settings;
-        settings._showAll = true;
-        settings._checkCodingStyle = true;
+        settings._showAll = all;
+        settings._checkCodingStyle = style;
 
         // Check for unsigned divisions..
         CheckOther checkOther(&tokenizer, &settings, this);
-        checkOther.CheckUnsignedDivision();
+        checkOther.checkUnsignedDivision();
     }
 
     void run()
@@ -64,6 +64,7 @@ private:
         TEST_CASE(division5);
         TEST_CASE(division6);
         TEST_CASE(division7);
+        TEST_CASE(division8);
     }
 
     void division1()
@@ -74,7 +75,7 @@ private:
               "    unsigned int uvar = 2;\n"
               "    return ivar / uvar;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:5]: (all style) Warning: Division with signed and unsigned operators\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:5]: (possible style) Division with signed and unsigned operators\n", errout.str());
     }
 
     void division2()
@@ -85,7 +86,7 @@ private:
               "    unsigned int uvar = 2;\n"
               "    return uvar / ivar;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:5]: (all style) Warning: Division with signed and unsigned operators\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:5]: (possible style) Division with signed and unsigned operators\n", errout.str());
     }
 
     void division3()
@@ -98,7 +99,7 @@ private:
               "    u32 uvar = 2;\n"
               "    return uvar / ivar;\n"
               "}\n");
-        ASSERT_EQUALS("[test.cpp:7]: (all style) Warning: Division with signed and unsigned operators\n", errout.str());
+        ASSERT_EQUALS("[test.cpp:7]: (possible style) Division with signed and unsigned operators\n", errout.str());
     }
 
     void division4()
@@ -146,6 +147,47 @@ private:
              );
         ASSERT_EQUALS("[test.cpp:4]: (error) Unsigned division. The result will be wrong.\n", errout.str());
     }
+
+    void division8()
+    {
+        check("void foo(int b)\n"
+              "{\n"
+              "    if (b > 0)\n"
+              "    {\n"
+              "         unsigned int a;\n"
+              "         unsigned int c = a / b;\n"
+              "    }\n"
+              "}\n", false, true);
+        ASSERT_EQUALS("", errout.str());
+
+        check("void foo(int b)\n"
+              "{\n"
+              "    if (b > 0)\n"
+              "    {\n"
+              "         unsigned int a;\n"
+              "         unsigned int c = a / b;\n"
+              "    }\n"
+              "}\n", true, false);
+        ASSERT_EQUALS("", errout.str());
+
+        check("void foo(int b)\n"
+              "{\n"
+              "    if (b > 0)\n"
+              "    {\n"
+              "         unsigned int a;\n"
+              "         unsigned int c = a / b;\n"
+              "    }\n"
+              "}\n", true, true);
+        ASSERT_EQUALS("[test.cpp:6]: (possible style) Division with signed and unsigned operators\n", errout.str());
+
+        check("void a(int i) { }\n"
+              "int foo( unsigned int sz )\n"
+              "{\n"
+              "    register unsigned int i=1;\n"
+              "    return i/sz;\n"
+              "}\n", true, true);
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestDivision)
