@@ -13,12 +13,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string>
 #include "testsuite.h"
-#include "../src/filelister.h"
+#include "filelister.h"
 
 class TestFileLister : public TestFixture
 {
