@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -22,8 +22,8 @@
 
 
 #include "testsuite.h"
-#include "../src/tokenize.h"
-#include "../src/checkother.h"
+#include "tokenize.h"
+#include "checkother.h"
 
 #include <sstream>
 
@@ -52,7 +52,7 @@ private:
 
         // Check for unused variables..
         CheckOther checkOther(&tokenizer, &settings, this);
-        checkOther.CheckIncompleteStatement();
+        checkOther.checkIncompleteStatement();
     }
 
     void run()
