@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <cstdlib>
 #include "testsuite.h"
-#include <string>
-#include <vector>
 
 int main(int argc, const char *argv[])
 {
-    TestFixture::runTests((argc == 2) ? argv[1] : NULL);
-    return 0;
+    size_t ret = TestFixture::runTests((argc == 2) ? argv[1] : NULL);
+
+    return (ret == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
 
