@@ -13,14 +13,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
-
+#ifndef testsuiteH
+#define testsuiteH
 
 #include <sstream>
-#include "../src/errorlogger.h"
+#include "errorlogger.h"
 
 class Token;
 
@@ -29,6 +30,7 @@ class TestFixture : public ErrorLogger
 private:
     static std::ostringstream errmsg;
     static unsigned int countTests;
+    static size_t fails_counter;
 
 protected:
     std::string classname;
@@ -52,7 +54,7 @@ public:
     virtual ~TestFixture() { }
 
     static void printTests();
-    static void runTests(const char cmd[]);
+    static size_t runTests(const char cmd[]);
 };
 
 
@@ -62,3 +64,5 @@ public:
 #define TODO_ASSERT_EQUALS( EXPECTED , ACTUAL ) if (EXPECTED==ACTUAL) assertEquals(__FILE__, __LINE__, "TODO assertion", "The assertion succeeded")
 #define REGISTER_TEST( CLASSNAME ) namespace { CLASSNAME instance; }
 
+#endif
+
