@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 // Generate Makefile for cppcheck
@@ -23,7 +23,7 @@
 #include <iostream>
 #include <string>
 #include <vector>
-#include "../src/filelister.h"
+#include "../lib/filelister.h"
 
 std::string objfile(std::string cppfile)
 {
@@ -33,9 +33,17 @@ std::string objfile(std::string cppfile)
 
 void getDeps(const std::string &filename, std::vector<std::string> &depfiles)
 {
+    // Is the dependency already included?
+    if (std::find(depfiles.begin(), depfiles.end(), filename) != depfiles.end())
+        return;
+
     std::ifstream f(filename.c_str());
     if (! f.is_open())
+    {
+        if (filename.compare(0, 4, "cli/") == 0 || filename.compare(0, 5, "test/") == 0)
+            getDeps("lib" + filename.substr(filename.find("/")), depfiles);
         return;
+    }
     if (filename.find(".c") == std::string::npos)
         depfiles.push_back(filename);
 
@@ -55,24 +63,34 @@ void getDeps(const std::string &filename, std::vector<std::string> &depfiles)
         std::string hfile(path + line.substr(pos1, pos2 - pos1));
         if (hfile.find("/../") != std::string::npos)	// TODO: Ugly fix
             hfile.erase(0, 4 + hfile.find("/../"));
-        if (std::find(depfiles.begin(), depfiles.end(), hfile) != depfiles.end())
-            continue;
         getDeps(hfile, depfiles);
     }
 }
 
+static void compilefiles(std::ostream &fout, const std::vector<std::string> &files)
+{
+    for (unsigned int i = 0; i < files.size(); ++i)
+    {
+        fout << objfile(files[i]) << ": " << files[i];
+        std::vector<std::string> depfiles;
+        getDeps(files[i], depfiles);
+        for (unsigned int dep = 0; dep < depfiles.size(); ++dep)
+            fout << " " << depfiles[dep];
+        fout << "\n\t$(CXX) $(CXXFLAGS) -Ilib -c -o " << objfile(files[i]) << " " << files[i] << "\n\n";
+    }
+}
+
 int main()
 {
     // Get files..
-    std::vector<std::string> srcfiles;
-    FileLister::RecursiveAddFiles(srcfiles, "src/", true);
-    if (srcfiles.empty())
-    {
-        std::cout << "No source files found." << std::endl;
-        exit(1);
-    }
+    std::vector<std::string> libfiles;
+    FileLister::recursiveAddFiles(libfiles, "lib/", true);
+
+    std::vector<std::string> clifiles;
+    FileLister::recursiveAddFiles(clifiles, "cli/", true);
+
     std::vector<std::string> testfiles;
-    FileLister::RecursiveAddFiles(testfiles, "test/", true);
+    FileLister::recursiveAddFiles(testfiles, "test/", true);
 
     std::ofstream fout("Makefile");
 
@@ -80,63 +98,50 @@ int main()
     fout << "CXXFLAGS=-Wall -Wextra -pedantic -g\n";
     fout << "CXX=g++\n";
     fout << "BIN=${DESTDIR}/usr/bin\n\n";
+    fout << "# For 'make man': sudo apt-get install xsltproc docbook-xsl docbook-xml\n";
+    fout << "DB2MAN=/usr/share/sgml/docbook/stylesheet/xsl/nwalsh/manpages/docbook.xsl\n";
+    fout << "XP=xsltproc -''-nonet -''-param man.charmap.use.subset \"0\"\n";
+    fout << "MAN_SOURCE=man/cppcheck.1.xml\n\n";
 
     fout << "\n###### Object Files\n\n";
-    fout << "OBJECTS =     " << objfile(srcfiles[0]);
-    for (unsigned int i = 1; i < srcfiles.size(); ++i)
-        fout << " \\" << std::endl << std::string(14, ' ') << objfile(srcfiles[i]);
+    fout << "LIBOBJ =     " << objfile(libfiles[0]);
+    for (unsigned int i = 1; i < libfiles.size(); ++i)
+        fout << " \\" << std::endl << std::string(14, ' ') << objfile(libfiles[i]);
+    fout << "\n\n";
+    fout << "CLIOBJ =     " << objfile(clifiles[0]);
+    for (unsigned int i = 1; i < clifiles.size(); ++i)
+        fout << " \\" << std::endl << std::string(14, ' ') << objfile(clifiles[i]);
     fout << "\n\n";
     fout << "TESTOBJ =     " << objfile(testfiles[0]);
     for (unsigned int i = 1; i < testfiles.size(); ++i)
         fout << " \\" << std::endl << std::string(14, ' ') << objfile(testfiles[i]);
-    for (unsigned int i = 0; i < srcfiles.size(); ++i)
-    {
-        if (srcfiles[i] != "src/main.cpp")
-            fout << " \\" << std::endl << std::string(14, ' ') << objfile(srcfiles[i]);
-    }
     fout << "\n\n";
 
 
     fout << "\n###### Targets\n\n";
-    fout << "cppcheck:\t$(OBJECTS)\n";
-    fout << "\t$(CXX) $(CXXFLAGS) -o cppcheck $(OBJECTS) $(LDFLAGS)\n\n";
+    fout << "cppcheck:\t$(LIBOBJ)\t$(CLIOBJ)\n";
+    fout << "\t$(CXX) $(CXXFLAGS) -o cppcheck $(CLIOBJ) $(LIBOBJ) $(LDFLAGS)\n\n";
     fout << "all:\tcppcheck\ttestrunner\ttools\n\n";
-    fout << "testrunner:\t$(TESTOBJ)\n";
-    fout << "\t$(CXX) $(CXXFLAGS) -o testrunner $(TESTOBJ) $(LDFLAGS)\n\n";
+    fout << "testrunner:\t$(TESTOBJ)\t$(LIBOBJ)\n";
+    fout << "\t$(CXX) $(CXXFLAGS) -o testrunner $(TESTOBJ) $(LIBOBJ) $(LDFLAGS)\n\n";
     fout << "test:\tall\n";
     fout << "\t./testrunner\n\n";
-    fout << "tools:\ttools/errmsg\ttools/dmake\n\n";
-    fout << "tools/errmsg:\ttools/errmsg.cpp\n";
-    fout << "\t$(CXX) $(CXXFLAGS) -o tools/errmsg tools/errmsg.cpp $(LDFLAGS)\n\n";
-    fout << "tools/dmake:\ttools/dmake.cpp\tsrc/filelister.cpp\tsrc/filelister.h\n";
-    fout << "\t$(CXX) $(CXXFLAGS) -o tools/dmake tools/dmake.cpp src/filelister.cpp $(LDFLAGS)\n\n";
+    fout << "tools:\ttools/dmake\n\n";
+    fout << "tools/dmake:\ttools/dmake.cpp\tlib/filelister.cpp\tlib/filelister.h\n";
+    fout << "\t$(CXX) $(CXXFLAGS) -o tools/dmake tools/dmake.cpp lib/filelister.cpp $(LDFLAGS)\n\n";
     fout << "clean:\n";
-    fout << "\trm -f src/*.o test/*.o testrunner cppcheck tools/dmake tools/errmsg\n\n";
+    fout << "\trm -f lib/*.o cli/*.o test/*.o testrunner cppcheck tools/dmake\n\n";
+    fout << "man:\t$(MAN_SOURCE)\n";
+    fout << "\t$(XP) $(DB2MAN) $(MAN_SOURCE)\n\n";
     fout << "install:\tcppcheck\n";
     fout << "\tinstall -d ${BIN}\n";
     fout << "\tinstall cppcheck ${BIN}\n\n";
 
     fout << "\n###### Build\n\n";
 
-    for (unsigned int i = 0; i < srcfiles.size(); ++i)
-    {
-        fout << objfile(srcfiles[i]) << ": " << srcfiles[i];
-        std::vector<std::string> depfiles;
-        getDeps(srcfiles[i], depfiles);
-        for (unsigned int dep = 0; dep < depfiles.size(); ++dep)
-            fout << " " << depfiles[dep];
-        fout << "\n\t$(CXX) $(CXXFLAGS) -c -o " << objfile(srcfiles[i]) << " " << srcfiles[i] << "\n\n";
-    }
-
-    for (unsigned int i = 0; i < testfiles.size(); ++i)
-    {
-        fout << objfile(testfiles[i]) << ": " << testfiles[i];
-        std::vector<std::string> depfiles;
-        getDeps(testfiles[i], depfiles);
-        for (unsigned int dep = 0; dep < depfiles.size(); ++dep)
-            fout << " " << depfiles[dep];
-        fout << "\n\t$(CXX) $(CXXFLAGS) -c -o " << objfile(testfiles[i]) << " " << testfiles[i] << "\n\n";
-    }
+    compilefiles(fout, libfiles);
+    compilefiles(fout, clifiles);
+    compilefiles(fout, testfiles);
 
     return 0;
 }
